@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2023 Red Hat, Inc.
+ * Copyright (c) 2012-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -14,7 +14,6 @@ package org.eclipse.che.api.factory.server.scm.kubernetes;
 import static com.google.common.base.Strings.isNullOrEmpty;
 import static org.eclipse.che.commons.lang.StringUtils.trimEnd;
 
-import com.google.common.annotations.VisibleForTesting;
 import com.google.common.collect.ImmutableMap;
 import io.fabric8.kubernetes.api.model.LabelSelector;
 import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
@@ -48,6 +47,8 @@ import org.eclipse.che.commons.subject.Subject;
 import org.eclipse.che.workspace.infrastructure.kubernetes.CheServerKubernetesClientFactory;
 import org.eclipse.che.workspace.infrastructure.kubernetes.api.shared.KubernetesNamespaceMeta;
 import org.eclipse.che.workspace.infrastructure.kubernetes.namespace.KubernetesNamespaceFactory;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /** Manages personal access token secrets used for private repositories authentication. */
 @Singleton
@@ -75,6 +76,9 @@ public class KubernetesPersonalAccessTokenManager implements PersonalAccessToken
   private final ScmPersonalAccessTokenFetcher scmPersonalAccessTokenFetcher;
   private final GitCredentialManager gitCredentialManager;
 
+  private static final Logger LOG =
+      LoggerFactory.getLogger(KubernetesPersonalAccessTokenManager.class);
+
   @Inject
   public KubernetesPersonalAccessTokenManager(
       KubernetesNamespaceFactory namespaceFactory,
@@ -87,8 +91,8 @@ public class KubernetesPersonalAccessTokenManager implements PersonalAccessToken
     this.gitCredentialManager = gitCredentialManager;
   }
 
-  @VisibleForTesting
-  void save(PersonalAccessToken personalAccessToken)
+  @Override
+  public void store(PersonalAccessToken personalAccessToken)
       throws UnsatisfiedScmPreconditionException, ScmConfigurationPersistenceException {
     try {
       String namespace = getFirstNamespace();
@@ -136,14 +140,13 @@ public class KubernetesPersonalAccessTokenManager implements PersonalAccessToken
           ScmUnauthorizedException, ScmCommunicationException, UnknownScmProviderException {
     PersonalAccessToken personalAccessToken =
         scmPersonalAccessTokenFetcher.fetchPersonalAccessToken(cheUser, scmServerUrl);
-    save(personalAccessToken);
+    store(personalAccessToken);
     return personalAccessToken;
   }
 
   @Override
   public Optional<PersonalAccessToken> get(Subject cheUser, String scmServerUrl)
-      throws ScmConfigurationPersistenceException, ScmUnauthorizedException,
-          ScmCommunicationException {
+      throws ScmConfigurationPersistenceException {
     return doGetPersonalAccessToken(cheUser, null, scmServerUrl);
   }
 
@@ -165,16 +168,18 @@ public class KubernetesPersonalAccessTokenManager implements PersonalAccessToken
   @Override
   public Optional<PersonalAccessToken> get(
       Subject cheUser, String oAuthProviderName, @Nullable String scmServerUrl)
-      throws ScmConfigurationPersistenceException, ScmUnauthorizedException,
-          ScmCommunicationException {
+      throws ScmConfigurationPersistenceException {
     return doGetPersonalAccessToken(cheUser, oAuthProviderName, scmServerUrl);
   }
 
   private Optional<PersonalAccessToken> doGetPersonalAccessToken(
       Subject cheUser, @Nullable String oAuthProviderName, @Nullable String scmServerUrl)
-      throws ScmConfigurationPersistenceException, ScmUnauthorizedException,
-          ScmCommunicationException {
+      throws ScmConfigurationPersistenceException {
     try {
+      LOG.debug(
+          "Fetching personal access token for user {} and OAuth provider {}",
+          cheUser.getUserId(),
+          oAuthProviderName);
       for (KubernetesNamespaceMeta namespaceMeta : namespaceFactory.list()) {
         List<Secret> secrets =
             namespaceFactory
@@ -182,17 +187,24 @@ public class KubernetesPersonalAccessTokenManager implements PersonalAccessToken
                 .secrets()
                 .get(KUBERNETES_PERSONAL_ACCESS_TOKEN_LABEL_SELECTOR);
         for (Secret secret : secrets) {
+          LOG.debug("Checking secret {}", secret.getMetadata().getName());
           if (deleteSecretIfMisconfigured(secret)) {
+            LOG.debug("Secret {} is misconfigured and was deleted", secret.getMetadata().getName());
             continue;
           }
 
           if (isSecretMatchesSearchCriteria(cheUser, oAuthProviderName, scmServerUrl, secret)) {
+            LOG.debug("Iterating over secret {}", secret.getMetadata().getName());
             PersonalAccessTokenParams personalAccessTokenParams =
                 this.secret2PersonalAccessTokenParams(secret);
             Optional<String> scmUsername =
                 scmPersonalAccessTokenFetcher.getScmUsername(personalAccessTokenParams);
 
             if (scmUsername.isPresent()) {
+              LOG.debug(
+                  "Creating personal access token for user {} and OAuth provider {}",
+                  cheUser.getUserId(),
+                  oAuthProviderName);
               Map<String, String> secretAnnotations = secret.getMetadata().getAnnotations();
 
               PersonalAccessToken personalAccessToken =
@@ -216,10 +228,12 @@ public class KubernetesPersonalAccessTokenManager implements PersonalAccessToken
                 .secrets()
                 .inNamespace(namespaceMeta.getName())
                 .delete(secret);
+            LOG.debug("Secret {} is misconfigured and was deleted", secret.getMetadata().getName());
           }
         }
       }
     } catch (InfrastructureException | UnknownScmProviderException e) {
+      LOG.debug("Failed to get personal access token", e);
       throw new ScmConfigurationPersistenceException(e.getMessage(), e);
     }
     return Optional.empty();
@@ -294,7 +308,7 @@ public class KubernetesPersonalAccessTokenManager implements PersonalAccessToken
   }
 
   @Override
-  public void store(String scmServerUrl)
+  public void storeGitCredentials(String scmServerUrl)
       throws UnsatisfiedScmPreconditionException, ScmConfigurationPersistenceException,
           ScmCommunicationException, ScmUnauthorizedException {
     Subject subject = EnvironmentContext.getCurrent().getSubject();
