@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2023 Red Hat, Inc.
+ * Copyright (c) 2012-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -142,7 +142,7 @@ public class KubernetesPersonalAccessTokenManagerTest {
             "https://bitbucket.com", "cheUser", "username", "token-name", "tid-24", "token123");
 
     // when
-    personalAccessTokenManager.save(token);
+    personalAccessTokenManager.store(token);
 
     // then
     verify(nonNamespaceOperation).createOrReplace(captor.capture());
