@@ -71,6 +71,8 @@ import org.eclipse.che.commons.subject.SubjectImpl;
 import org.eclipse.che.inject.ConfigurationException;
 import org.eclipse.che.workspace.infrastructure.kubernetes.CheServerKubernetesClientFactory;
 import org.eclipse.che.workspace.infrastructure.kubernetes.api.shared.KubernetesNamespaceMeta;
+import org.eclipse.che.workspace.infrastructure.kubernetes.authorization.AuthorizationChecker;
+import org.eclipse.che.workspace.infrastructure.kubernetes.authorization.PermissionsCleaner;
 import org.eclipse.che.workspace.infrastructure.kubernetes.namespace.KubernetesConfigsMaps;
 import org.eclipse.che.workspace.infrastructure.kubernetes.namespace.KubernetesSecrets;
 import org.eclipse.che.workspace.infrastructure.kubernetes.namespace.configurator.NamespaceConfigurator;
@@ -113,6 +115,8 @@ public class OpenShiftProjectFactoryTest {
   @Mock private WorkspaceManager workspaceManager;
   @Mock private PreferenceManager preferenceManager;
   @Mock private KubernetesSharedPool pool;
+  @Mock private AuthorizationChecker authorizationChecker;
+  @Mock private PermissionsCleaner permissionsCleaner;
 
   @Mock private ProjectOperation projectOperation;
 
@@ -134,6 +138,7 @@ public class OpenShiftProjectFactoryTest {
     lenient().when(cheServerOpenshiftClientFactory.createOC()).thenReturn(osClient);
     lenient().when(cheServerKubernetesClientFactory.create()).thenReturn(osClient);
     lenient().when(osClient.projects()).thenReturn(projectOperation);
+    lenient().when(authorizationChecker.isAuthorized(anyString())).thenReturn(true);
 
     lenient()
         .when(workspaceManager.getWorkspace(any()))
@@ -174,6 +179,8 @@ public class OpenShiftProjectFactoryTest {
             cheServerOpenshiftClientFactory,
             preferenceManager,
             pool,
+            authorizationChecker,
+            permissionsCleaner,
             NO_OAUTH_IDENTITY_PROVIDER);
 
     projectFactory.checkIfNamespaceIsAllowed(USER_NAME + "-che");
@@ -204,6 +211,8 @@ public class OpenShiftProjectFactoryTest {
             cheServerOpenshiftClientFactory,
             preferenceManager,
             pool,
+            authorizationChecker,
+            permissionsCleaner,
             NO_OAUTH_IDENTITY_PROVIDER);
     try {
       projectFactory.checkIfNamespaceIsAllowed("any-namespace");
@@ -234,6 +243,8 @@ public class OpenShiftProjectFactoryTest {
             cheServerOpenshiftClientFactory,
             preferenceManager,
             pool,
+            authorizationChecker,
+            permissionsCleaner,
             NO_OAUTH_IDENTITY_PROVIDER);
   }
 
@@ -269,6 +280,8 @@ public class OpenShiftProjectFactoryTest {
             cheServerOpenshiftClientFactory,
             preferenceManager,
             pool,
+            authorizationChecker,
+            permissionsCleaner,
             NO_OAUTH_IDENTITY_PROVIDER);
     EnvironmentContext.getCurrent().setSubject(new SubjectImpl("jondoe", "123", null, false));
 
@@ -305,6 +318,8 @@ public class OpenShiftProjectFactoryTest {
             cheServerOpenshiftClientFactory,
             preferenceManager,
             pool,
+            authorizationChecker,
+            permissionsCleaner,
             NO_OAUTH_IDENTITY_PROVIDER);
     EnvironmentContext.getCurrent().setSubject(new SubjectImpl("jondoe", "u123", null, false));
 
@@ -337,6 +352,8 @@ public class OpenShiftProjectFactoryTest {
             cheServerOpenshiftClientFactory,
             preferenceManager,
             pool,
+            authorizationChecker,
+            permissionsCleaner,
             NO_OAUTH_IDENTITY_PROVIDER);
 
     // when
@@ -379,6 +396,8 @@ public class OpenShiftProjectFactoryTest {
             cheServerOpenshiftClientFactory,
             preferenceManager,
             pool,
+            authorizationChecker,
+            permissionsCleaner,
             NO_OAUTH_IDENTITY_PROVIDER);
 
     List<KubernetesNamespaceMeta> availableNamespaces = projectFactory.list();
@@ -415,6 +434,8 @@ public class OpenShiftProjectFactoryTest {
             cheServerOpenshiftClientFactory,
             preferenceManager,
             pool,
+            authorizationChecker,
+            permissionsCleaner,
             NO_OAUTH_IDENTITY_PROVIDER);
 
     List<KubernetesNamespaceMeta> availableNamespaces = projectFactory.list();
@@ -451,6 +472,8 @@ public class OpenShiftProjectFactoryTest {
             cheServerOpenshiftClientFactory,
             preferenceManager,
             pool,
+            authorizationChecker,
+            permissionsCleaner,
             NO_OAUTH_IDENTITY_PROVIDER);
 
     projectFactory.list();
@@ -477,6 +500,8 @@ public class OpenShiftProjectFactoryTest {
             cheServerOpenshiftClientFactory,
             preferenceManager,
             pool,
+            authorizationChecker,
+            permissionsCleaner,
             NO_OAUTH_IDENTITY_PROVIDER);
 
     projectFactory.list();
@@ -508,6 +533,8 @@ public class OpenShiftProjectFactoryTest {
                 cheServerOpenshiftClientFactory,
                 preferenceManager,
                 pool,
+                authorizationChecker,
+                permissionsCleaner,
                 NO_OAUTH_IDENTITY_PROVIDER));
     OpenShiftProject toReturnProject = mock(OpenShiftProject.class);
     prepareProject(toReturnProject);
@@ -542,6 +569,8 @@ public class OpenShiftProjectFactoryTest {
                 cheServerOpenshiftClientFactory,
                 preferenceManager,
                 pool,
+                authorizationChecker,
+                permissionsCleaner,
                 NO_OAUTH_IDENTITY_PROVIDER));
     OpenShiftProject toReturnProject = mock(OpenShiftProject.class);
     doReturn(toReturnProject).when(projectFactory).doCreateProjectAccess(any(), any());
@@ -584,6 +613,8 @@ public class OpenShiftProjectFactoryTest {
                 cheServerOpenshiftClientFactory,
                 preferenceManager,
                 pool,
+                authorizationChecker,
+                permissionsCleaner,
                 NO_OAUTH_IDENTITY_PROVIDER));
     OpenShiftProject toReturnProject = mock(OpenShiftProject.class);
     prepareProject(toReturnProject);
@@ -628,6 +659,8 @@ public class OpenShiftProjectFactoryTest {
                 cheServerOpenshiftClientFactory,
                 preferenceManager,
                 pool,
+                authorizationChecker,
+                permissionsCleaner,
                 OAUTH_IDENTITY_PROVIDER));
     OpenShiftProject toReturnProject = mock(OpenShiftProject.class);
     when(toReturnProject.getName()).thenReturn("workspace123");
@@ -677,6 +710,8 @@ public class OpenShiftProjectFactoryTest {
             cheServerOpenshiftClientFactory,
             preferenceManager,
             pool,
+            authorizationChecker,
+            permissionsCleaner,
             NO_OAUTH_IDENTITY_PROVIDER);
 
     String namespace =
@@ -709,6 +744,8 @@ public class OpenShiftProjectFactoryTest {
             cheServerOpenshiftClientFactory,
             preferenceManager,
             pool,
+            authorizationChecker,
+            permissionsCleaner,
             NO_OAUTH_IDENTITY_PROVIDER);
     EnvironmentContext.getCurrent().setSubject(new SubjectImpl("jondoe", "123", null, false));
     projectFactory.list();
@@ -735,6 +772,8 @@ public class OpenShiftProjectFactoryTest {
                 cheServerOpenshiftClientFactory,
                 preferenceManager,
                 pool,
+                authorizationChecker,
+                permissionsCleaner,
                 NO_OAUTH_IDENTITY_PROVIDER));
     EnvironmentContext.getCurrent().setSubject(new SubjectImpl("jondoe", "123", null, false));
     OpenShiftProject toReturnProject = mock(OpenShiftProject.class);
@@ -775,6 +814,8 @@ public class OpenShiftProjectFactoryTest {
                 cheServerOpenshiftClientFactory,
                 preferenceManager,
                 pool,
+                authorizationChecker,
+                permissionsCleaner,
                 NO_OAUTH_IDENTITY_PROVIDER));
     EnvironmentContext.getCurrent().setSubject(new SubjectImpl("jondoe", "123", null, false));
 
