@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2023 Red Hat, Inc.
+ * Copyright (c) 2012-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -14,6 +14,7 @@ package org.eclipse.che.security.oauth;
 import static com.google.common.base.Strings.isNullOrEmpty;
 import static java.nio.charset.StandardCharsets.UTF_8;
 import static java.util.Collections.emptyList;
+import static org.eclipse.che.api.factory.server.scm.PersonalAccessTokenFetcher.OAUTH_2_PREFIX;
 import static org.eclipse.che.commons.lang.UrlUtils.*;
 import static org.eclipse.che.commons.lang.UrlUtils.getParameter;
 import static org.eclipse.che.dto.server.DtoFactory.newDto;
@@ -40,7 +41,13 @@ import org.eclipse.che.api.core.UnauthorizedException;
 import org.eclipse.che.api.core.rest.shared.dto.Link;
 import org.eclipse.che.api.core.rest.shared.dto.LinkParameter;
 import org.eclipse.che.api.core.util.LinksHelper;
+import org.eclipse.che.api.factory.server.scm.PersonalAccessToken;
+import org.eclipse.che.api.factory.server.scm.PersonalAccessTokenManager;
+import org.eclipse.che.api.factory.server.scm.exception.ScmConfigurationPersistenceException;
+import org.eclipse.che.api.factory.server.scm.exception.UnsatisfiedScmPreconditionException;
+import org.eclipse.che.commons.annotation.Nullable;
 import org.eclipse.che.commons.env.EnvironmentContext;
+import org.eclipse.che.commons.lang.NameGenerator;
 import org.eclipse.che.commons.subject.Subject;
 import org.eclipse.che.security.oauth.shared.dto.OAuthAuthenticatorDescriptor;
 import org.slf4j.Logger;
@@ -62,6 +69,7 @@ public class EmbeddedOAuthAPI implements OAuthAPI {
 
   @Inject protected OAuthAuthenticatorProvider oauth2Providers;
   @Inject protected org.eclipse.che.security.oauth1.OAuthAuthenticatorProvider oauth1Providers;
+  @Inject private PersonalAccessTokenManager personalAccessTokenManager;
   private String redirectAfterLogin;
 
   @Override
@@ -80,29 +88,73 @@ public class EmbeddedOAuthAPI implements OAuthAPI {
   }
 
   @Override
-  public Response callback(UriInfo uriInfo, List<String> errorValues) throws NotFoundException {
+  public Response callback(UriInfo uriInfo, @Nullable List<String> errorValues)
+      throws NotFoundException {
     URL requestUrl = getRequestUrl(uriInfo);
     Map<String, List<String>> params = getQueryParametersFromState(getState(requestUrl));
     errorValues = errorValues == null ? uriInfo.getQueryParameters().get("error") : errorValues;
     if (!isNullOrEmpty(redirectAfterLogin)
         && errorValues != null
         && errorValues.contains("access_denied")) {
-      return Response.temporaryRedirect(URI.create(encodeRedirectUrl())).build();
+      return Response.temporaryRedirect(
+              URI.create(encodeRedirectUrl(redirectAfterLogin + "&error_code=access_denied")))
+          .build();
     }
     final String providerName = getParameter(params, "oauth_provider");
     OAuthAuthenticator oauth = getAuthenticator(providerName);
     final List<String> scopes = params.get("scope");
     try {
-      oauth.callback(requestUrl, scopes == null ? emptyList() : scopes);
+      String token = oauth.callback(requestUrl, scopes == null ? emptyList() : scopes);
+      personalAccessTokenManager.store(
+          new PersonalAccessToken(
+              oauth.getEndpointUrl(),
+              EnvironmentContext.getCurrent().getSubject().getUserId(),
+              null,
+              null,
+              generateTokenName(providerName),
+              NameGenerator.generate("id-", 5),
+              token));
     } catch (OAuthAuthenticationException e) {
       return Response.temporaryRedirect(
               URI.create(
                   getParameter(params, "redirect_after_login")
                       + String.format("&%s=access_denied", ERROR_QUERY_NAME)))
           .build();
+    } catch (UnsatisfiedScmPreconditionException | ScmConfigurationPersistenceException e) {
+      // Skip exception, the token will be stored in the next request.
+      LOG.error(e.getMessage(), e);
     }
-    final String redirectAfterLogin = getParameter(params, "redirect_after_login");
-    return Response.temporaryRedirect(URI.create(redirectAfterLogin)).build();
+    return Response.temporaryRedirect(URI.create(getRedirectAfterLoginUrl(params))).build();
+  }
+
+  /**
+   * Returns the redirect after login URL from the query parameters. If the URL is encoded by the
+   * CSM provider, it will be decoded, to avoid unsupported characters in the URL.
+   *
+   * @param parameters the query parameters
+   * @return the redirect after login URL
+   */
+  public static String getRedirectAfterLoginUrl(Map<String, List<String>> parameters) {
+    String redirectAfterLogin = getParameter(parameters, "redirect_after_login");
+    try {
+      URI.create(redirectAfterLogin);
+    } catch (IllegalArgumentException e) {
+      // the redirectUrl was decoded by the CSM provider, so we need to encode it back.
+      redirectAfterLogin = encodeRedirectUrl(redirectAfterLogin);
+    }
+    return redirectAfterLogin;
+  }
+
+  /*
+   * This value is used for generating git credentials. Most of the git providers work with git
+   * credentials with OAuth token in format "ouath2:<oauth token>" but bitbucket requires username
+   * to be explicitly set: "<username>:<oauth token>, see {@link
+   * GitCredentialManager#createOrReplace}
+   * TODO: needs to be moved to the specific bitbucket implementation.
+   */
+  private String generateTokenName(String providerName) {
+    return NameGenerator.generate(
+        "bitbucket".equals(providerName) ? providerName + "-" : OAUTH_2_PREFIX, 5);
   }
 
   /**
@@ -110,12 +162,10 @@ public class EmbeddedOAuthAPI implements OAuthAPI {
    * JSON, as a query parameter. This prevents passing unsupported characters, like '{' and '}' to
    * the {@link URI#create(String)} method.
    */
-  private String encodeRedirectUrl() {
+  private static String encodeRedirectUrl(String url) {
     try {
-      URL url = new URL(redirectAfterLogin);
-      String query = url.getQuery();
-      return redirectAfterLogin.substring(0, redirectAfterLogin.indexOf(query))
-          + URLEncoder.encode(query + "&error_code=access_denied", UTF_8);
+      String query = new URL(url).getQuery();
+      return url.substring(0, url.indexOf(query)) + URLEncoder.encode(query, UTF_8);
     } catch (MalformedURLException e) {
       LOG.error(e.getMessage(), e);
       throw new RuntimeException(e);
@@ -176,6 +226,19 @@ public class EmbeddedOAuthAPI implements OAuthAPI {
       }
       if (token != null) {
         return token;
+      } else {
+        Optional<PersonalAccessToken> tokenOptional;
+        try {
+          tokenOptional = personalAccessTokenManager.get(subject, oauthProvider, null);
+          if (tokenOptional.isEmpty()) {
+            tokenOptional = personalAccessTokenManager.get(subject, provider.getEndpointUrl());
+          }
+          if (tokenOptional.isPresent()) {
+            return newDto(OAuthToken.class).withToken(tokenOptional.get().getToken());
+          }
+        } catch (ScmConfigurationPersistenceException e) {
+          throw new RuntimeException(e);
+        }
       }
       throw new UnauthorizedException(
           "OAuth token for user " + subject.getUserId() + " was not found");
