@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2023 Red Hat, Inc.
+ * Copyright (c) 2012-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -11,15 +11,26 @@
  */
 package org.eclipse.che.api.factory.server.github;
 
+import static com.github.tomakehurst.wiremock.client.WireMock.aResponse;
+import static com.github.tomakehurst.wiremock.client.WireMock.get;
+import static com.github.tomakehurst.wiremock.client.WireMock.stubFor;
+import static com.github.tomakehurst.wiremock.client.WireMock.urlEqualTo;
+import static com.github.tomakehurst.wiremock.core.WireMockConfiguration.wireMockConfig;
+import static java.net.HttpURLConnection.HTTP_UNAUTHORIZED;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.anyString;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 import static org.testng.Assert.assertEquals;
 import static org.testng.Assert.assertTrue;
 
+import com.github.tomakehurst.wiremock.WireMockServer;
+import com.github.tomakehurst.wiremock.client.WireMock;
+import com.github.tomakehurst.wiremock.common.Slf4jNotifier;
 import java.util.Optional;
 import org.eclipse.che.api.core.ApiException;
 import org.eclipse.che.api.factory.server.scm.PersonalAccessToken;
@@ -47,9 +58,17 @@ public class GithubURLParserTest {
   /** Instance of component that will be tested. */
   private GithubURLParser githubUrlParser;
 
+  WireMockServer wireMockServer;
+  WireMock wireMock;
+
   /** Setup objects/ */
   @BeforeMethod
   protected void start() throws ApiException {
+    wireMockServer =
+        new WireMockServer(wireMockConfig().notifier(new Slf4jNotifier(false)).dynamicPort());
+    wireMockServer.start();
+    WireMock.configureFor("localhost", wireMockServer.port());
+    wireMock = new WireMock("localhost", wireMockServer.port());
     this.personalAccessTokenManager = mock(PersonalAccessTokenManager.class);
     this.githubApiClient = mock(GithubApiClient.class);
 
@@ -89,7 +108,13 @@ public class GithubURLParserTest {
   @Test(dataProvider = "parsingBadRepository")
   public void checkParsingBadRepositoryDoNotModifiesInitialInput(String url, String repository)
       throws ApiException {
+    // given
+    when(githubApiClient.isConnected(eq("https://github.com"))).thenReturn(true);
+
+    // when
     GithubUrl githubUrl = githubUrlParser.parse(url);
+
+    // then
     assertEquals(githubUrl.getRepository(), repository);
   }
 
@@ -189,6 +214,7 @@ public class GithubURLParserTest {
                     .withRef("pr-main-to-7.46.0")
                     .withUser(new GithubUser().withId(0).withName("eclipse").withLogin("eclipse"))
                     .withRepo(new GithubRepo().withName("che")));
+    when(githubApiClient.isConnected(eq("https://github.com"))).thenReturn(true);
     when(githubApiClient.getPullRequest(any(), any(), any(), any())).thenReturn(pr);
 
     GithubUrl githubUrl = githubUrlParser.parse(url);
@@ -215,6 +241,7 @@ public class GithubURLParserTest {
     when(personalAccessTokenManager.get(any(Subject.class), anyString()))
         .thenReturn(Optional.of(personalAccessToken));
 
+    when(githubApiClient.isConnected(eq("https://github.com"))).thenReturn(true);
     when(githubApiClient.getPullRequest(anyString(), anyString(), anyString(), anyString()))
         .thenReturn(pr);
 
@@ -239,6 +266,7 @@ public class GithubURLParserTest {
                     .withUser(new GithubUser().withId(0).withName("eclipse").withLogin("eclipse"))
                     .withRepo(new GithubRepo().withName("che")));
 
+    when(githubApiClient.isConnected(eq("https://github.com"))).thenReturn(true);
     when(githubApiClient.getPullRequest(any(), any(), any(), any())).thenReturn(pr);
 
     GithubUrl githubUrl = githubUrlParser.parseWithoutAuthentication(url);
@@ -261,10 +289,83 @@ public class GithubURLParserTest {
     when(personalAccessToken.getToken()).thenReturn("token");
     when(personalAccessTokenManager.get(any(Subject.class), anyString()))
         .thenReturn(Optional.of(personalAccessToken));
+    when(githubApiClient.isConnected(eq("https://github.com"))).thenReturn(true);
     when(githubApiClient.getPullRequest(anyString(), anyString(), anyString(), anyString()))
         .thenReturn(githubPullRequest);
 
     String url = "https://github.com/eclipse/che/pull/11103";
     githubUrlParser.parse(url);
   }
+
+  @Test
+  public void shouldParseServerUr() throws Exception {
+    // given
+    String url = "https://github-server.com/user/repo";
+
+    // when
+    GithubUrl githubUrl = githubUrlParser.parse(url);
+
+    // then
+    assertEquals(githubUrl.getUsername(), "user");
+    assertEquals(githubUrl.getRepository(), "repo");
+    assertEquals(githubUrl.getHostName(), "https://github-server.com");
+  }
+
+  @Test
+  public void shouldParseServerUrWithPullRequestId() throws Exception {
+    // given
+    String url = "https://github-server.com/user/repo/pull/11103";
+    GithubPullRequest pr =
+        new GithubPullRequest()
+            .withState("open")
+            .withHead(
+                new GithubHead()
+                    .withUser(new GithubUser().withId(0).withName("eclipse").withLogin("eclipse"))
+                    .withRepo(new GithubRepo().withName("che")));
+    when(githubApiClient.isConnected(eq("https://github-server.com"))).thenReturn(true);
+    when(githubApiClient.getPullRequest(any(), any(), any(), any())).thenReturn(pr);
+
+    // when
+    githubUrlParser.parse(url);
+
+    // then
+    verify(personalAccessTokenManager, times(2))
+        .get(any(Subject.class), eq("https://github-server.com"));
+  }
+
+  @Test
+  public void shouldValidateOldVersionGitHubServerUrl() throws Exception {
+    // given
+    String url = wireMockServer.url("/user/repo");
+    stubFor(
+        get(urlEqualTo("/api/v3/user"))
+            .willReturn(
+                aResponse()
+                    .withStatus(HTTP_UNAUTHORIZED)
+                    .withBody("{\"message\": \"Must authenticate to access this API.\",\n}")));
+
+    // when
+    boolean valid = githubUrlParser.isValid(url);
+
+    // then
+    assertTrue(valid);
+  }
+
+  @Test
+  public void shouldValidateGitHubServerUrl() throws Exception {
+    // given
+    String url = wireMockServer.url("/user/repo");
+    stubFor(
+        get(urlEqualTo("/api/v3/user"))
+            .willReturn(
+                aResponse()
+                    .withStatus(HTTP_UNAUTHORIZED)
+                    .withBody("{\"message\": \"Requires authentication\",\n}")));
+
+    // when
+    boolean valid = githubUrlParser.isValid(url);
+
+    // then
+    assertTrue(valid);
+  }
 }
