@@ -112,10 +112,12 @@ public class GitlabOAuthTokenFetcher implements PersonalAccessTokenFetcher {
           isValid(
               new PersonalAccessTokenParams(
                   scmServerUrl, tokenName, tokenId, oAuthToken.getToken(), null));
-      if (valid.isEmpty() || !valid.get().first) {
+      if (valid.isEmpty()) {
+        throw buildScmUnauthorizedException(cheSubject);
+      } else if (!valid.get().first) {
         throw new ScmCommunicationException(
-            "Current token doesn't have the necessary  privileges. Please make sure Che app scopes are correct and containing at least: "
-                + DEFAULT_TOKEN_SCOPES.toString());
+            "Current token doesn't have the necessary privileges. Please make sure Che app scopes are correct and containing at least: "
+                + DEFAULT_TOKEN_SCOPES);
       }
       return new PersonalAccessToken(
           scmServerUrl,
@@ -125,14 +127,7 @@ public class GitlabOAuthTokenFetcher implements PersonalAccessTokenFetcher {
           tokenId,
           oAuthToken.getToken());
     } catch (UnauthorizedException e) {
-      throw new ScmUnauthorizedException(
-          cheSubject.getUserName()
-              + " is not authorized in "
-              + OAUTH_PROVIDER_NAME
-              + " OAuth provider.",
-          OAUTH_PROVIDER_NAME,
-          "2.0",
-          getLocalAuthenticateUrl());
+      throw buildScmUnauthorizedException(cheSubject);
     } catch (NotFoundException nfe) {
       throw new UnknownScmProviderException(nfe.getMessage(), scmServerUrl);
     } catch (ServerException | ForbiddenException | BadRequestException | ConflictException e) {
@@ -141,6 +136,17 @@ public class GitlabOAuthTokenFetcher implements PersonalAccessTokenFetcher {
     }
   }
 
+  private ScmUnauthorizedException buildScmUnauthorizedException(Subject cheSubject) {
+    return new ScmUnauthorizedException(
+        cheSubject.getUserName()
+            + " is not authorized in "
+            + OAUTH_PROVIDER_NAME
+            + " OAuth provider.",
+        OAUTH_PROVIDER_NAME,
+        "2.0",
+        getLocalAuthenticateUrl());
+  }
+
   @Override
   public Optional<Boolean> isValid(PersonalAccessToken personalAccessToken) {
     GitlabApiClient gitlabApiClient = getApiClient(personalAccessToken.getScmProviderUrl());
