@@ -15,6 +15,7 @@ import java.util.Optional;
 import org.eclipse.che.api.factory.server.scm.exception.ScmCommunicationException;
 import org.eclipse.che.api.factory.server.scm.exception.ScmUnauthorizedException;
 import org.eclipse.che.api.factory.server.scm.exception.UnknownScmProviderException;
+import org.eclipse.che.commons.lang.Pair;
 import org.eclipse.che.commons.subject.Subject;
 
 public interface PersonalAccessTokenFetcher {
@@ -41,6 +42,7 @@ public interface PersonalAccessTokenFetcher {
    * Checks whether the provided personal access token is valid and has expected scope of
    * permissions.
    *
+   * @deprecated use {@link #isValid(PersonalAccessTokenParams)} instead.
    * @param personalAccessToken - personal access token to check.
    * @return - empty optional if {@link PersonalAccessTokenFetcher} is not able to confirm or deny
    *     that token is valid or {@link Boolean} value if it can.
@@ -49,6 +51,19 @@ public interface PersonalAccessTokenFetcher {
    * @throws ScmCommunicationException - Some unexpected problem occurred during communication with
    *     scm provider.
    */
+  @Deprecated
   Optional<Boolean> isValid(PersonalAccessToken personalAccessToken)
       throws ScmCommunicationException, ScmUnauthorizedException;
+
+  /**
+   * Checks whether the provided personal access token is valid by fetching user info from the scm
+   * provider. Also checks whether the token has expected scope of permissions if the provider API
+   * supports such request.
+   *
+   * @return - Optional with a pair of boolean value and scm username. The boolean value is true if
+   *     the token has expected scope of permissions, false if the token scopes does not match the
+   *     expected ones. Empty optional if {@link PersonalAccessTokenFetcher} is not able to confirm
+   *     or deny that token is valid.
+   */
+  Optional<Pair<Boolean, String>> isValid(PersonalAccessTokenParams params);
 }
